//
//  Standard includes
//
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

//
// Scheduler includes
//
#include "FreeRTOS.h"
#include "task.h"

//
//  Demo application includes
//
#include "main.h"
#include "adc/adc.h"
#include "cpu/cpu.h"
#include "dac/dac.h"
#include "eints/eints.h"
#include "gps/gps.h"
#include "fiq/fiq.h"
#include "i2c/i2c.h"
#include "iap/iap.h"
#include "leds/leds.h"
#include "monitor/monitor.h"
#include "rtc/rtc.h"
#include "sensors/sensors.h"
#include "uart/uart.h"
#include "usb/usb.h"

//
//
//
#define BAUD_UART0 115200
#define BAUD_UART1 4800

#ifdef CFG_CONSOLE_UART1
#undef BAUD_UART1
#define BAUD_UART1 115200
#endif

//
//
//
xTaskHandle taskHandles [TASKHANDLE_LAST];

//
//
//
int main (void)
{
  cpuSetupHardware ();
  uartInit (0, BAUD_UART0, 64);
  uartInit (1, BAUD_UART1, 64);
  usbInit ();
  rtcInit ();
  adcInit ();
  dacInit ();
  i2cInit ();
  eintsInit ();
  fiqInit ();
  iapInit ();

  memset (taskHandles, 0, sizeof (taskHandles));

  //
  //  This causes stdio to allocate buffers in the main area instead of on the task stack
  //
  printf ("LPC-P2148 Demo, Version " __VERSION ", " __DATE__ " " __TIME__ "\n");

  xTaskCreate (vSensorsTask,  (const signed portCHAR * const) "Sensors",  512,                      NULL, (configMAX_PRIORITIES - 2), &taskHandles [TASKHANDLE_SENSORS]);
#ifndef CFG_CONSOLE_UART1
  xTaskCreate (vGPSTask,      (const signed portCHAR * const) "GPS",      768,                      NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_GPS]);
#endif
  xTaskCreate (vMonitorTask,  (const signed portCHAR * const) "Monitor",  1024,                     NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_MONITOR]);
  xTaskCreate (vLEDFlashTask, (const signed portCHAR * const) "LEDx",     configMINIMAL_STACK_SIZE, NULL, (tskIDLE_PRIORITY + 1),     &taskHandles [TASKHANDLE_LED]);
  vTaskStartScheduler ();

  return 0;
}
